@@ -1,6 +1,7 @@
 from __future__ import division
 from django.db import models
 from django.conf import settings
+from django.db.models.sql.expressions import SQLEvaluator
 try:
     from django.utils.encoding import smart_unicode
 except ImportError:
@@ -91,7 +92,7 @@ class MoneyPatched(Money):
             super(MoneyPatched, self).__rmod__(other))
 
     def __get_current_locale(self):
-        locale = translation.get_language()
+        locale = translation.to_locale(translation.get_language())
 
         if _FORMATTER.get_formatting_definition(locale):
             return locale
@@ -197,14 +198,23 @@ class MoneyField(models.DecimalField):
 
     def __init__(self, verbose_name=None, name=None,
                  max_digits=None, decimal_places=None,
-                 default=Money(0.0, DEFAULT_CURRENCY),
+                 default=0.0,
                  default_currency=DEFAULT_CURRENCY,
                  currency_choices=CURRENCY_CHOICES, **kwargs):
 
         if isinstance(default, basestring):
-            amount, currency = default.split(" ")
+            try:
+                # handle scenario where default is formatted like:
+                # 'amount currency-code'
+                amount, currency = default.split(" ")
+            except ValueError:
+                # value error would be risen if the default is
+                # without the currency part, i.e
+                # 'amount'
+                amount = default
+                currency = default_currency
             default = Money(float(amount), Currency(code=currency))
-        elif isinstance(default, (float, Decimal)):
+        elif isinstance(default, (float, Decimal, int)):
             default = Money(default, default_currency)
 
         if not isinstance(default, Money):
@@ -233,6 +243,8 @@ class MoneyField(models.DecimalField):
                                          **kwargs)
 
     def to_python(self, value):
+        if isinstance(value, SQLEvaluator):
+            return value
         if isinstance(value, Money):
             value = value.amount
         if isinstance(value, tuple):
@@ -268,6 +280,8 @@ class MoneyField(models.DecimalField):
         setattr(cls, self.name, MoneyFieldProxy(self))
 
     def get_db_prep_save(self, value, connection):
+        if isinstance(value, SQLEvaluator):
+            return value
         if isinstance(value, Money):
             value = value.amount
             return value
